@@ -485,7 +485,7 @@ my $opt = {
     'next'      => 0,
     'set'       => 0,
     'bindir'    => "/cw/bin",
-    'probedir'  => "@libexecdir@",
+    'probedir'  => "@libexecdir@/snmpdx",
     'probename' => "*",
     'mibdir'    => "@datadir@/snmpdx/mibs",
     'mibname'   => "snmpdx",
